@@ -23,9 +23,7 @@
 #'
 #' blr_test_lr(model_1, model_2)
 #'
-#' @seealso \code{\link[lmtest]{lrtest}}
 #'
-#' @importFrom magrittr multiply_by subtract %<>%
 #' @importFrom stats coefficients pchisq formula
 #'
 #' @family model fit statistics
@@ -50,13 +48,11 @@ blr_test_lr.default <- function(full_model, reduced_model) {
   rm_class <- model_class(reduced_model)
 
   if (fm_class != "glm") {
-    stop(crayon::red("full_model must be an object of class glm."),
-         call. = FALSE)
+    stop("full_model must be an object of class glm.", call. = FALSE)
   }
 
   if (rm_class != "glm") {
-    stop(crayon::red("reduced_model must be an object of class glm."),
-      call. = FALSE)
+    stop("reduced_model must be an object of class glm.", call. = FALSE)
   }
 
   model_info <- lr_model_info(full_model, reduced_model)
@@ -65,7 +61,7 @@ blr_test_lr.default <- function(full_model, reduced_model) {
   result <- list(model_info = model_info, test_result = test_info)
   class(result) <- "blr_test_lr"
 
-  return(result)
+  invisible(result)
 
 }
 
@@ -78,12 +74,7 @@ print.blr_test_lr <- function(x, ...) {
 lr_reduced_model <- function(full_model) {
 
   dep <- response_var(full_model)
-
-  dat <-
-    full_model %>%
-    use_series(data)
-
-
+  dat <- full_model$data
   glm(paste0(dep, " ~ 1"), data = dat, family = binomial(link = "logit"))
 
 }
@@ -94,39 +85,24 @@ lr_test_result <- function(full_model, reduced_model) {
   reduced_model_ll <- mll(reduced_model)
   lr               <- reduced_model_ll - full_model_ll
 
-  df <-
-    full_model %>%
-    coefficients() %>%
-    length() %>%
-    subtract(1)
-
+  df   <- length(coefficients(full_model)) - 1
   pval <- pchisq(q = lr, df = df, lower.tail = FALSE)
 
-  tibble(lr_ratio = lr,
-         d_f      = df,
-         p_value  = pval)
+  data.frame(lr_ratio = lr,
+             d_f      = df,
+             p_value  = pval)
 
 }
 
 
 lr_model_info <- function(full_model, reduced_model) {
 
-  full_model_formula <-
-    full_model %>%
-    use_series(formula)
-
-  reduced_model_formula <-
-    reduced_model %>%
-    use_series(formula)
-
   full_model_df    <- model_d_f(full_model)
   reduced_model_df <- model_d_f(reduced_model)
   full_model_ll    <- mll(full_model)
   reduced_model_ll <- mll(reduced_model)
 
-  tibble(model = c("full model", "reduced model"),
-    formulas   = c(full_model    = full_model_formula,
-                   reduced_model = reduced_model_formula),
+  data.frame(model = c("full model", "reduced model"),
     log_lik    = c(full_model_ll, reduced_model_ll),
     d_f        = c(full_model_df, reduced_model_df)
   )
