@@ -1,6 +1,3 @@
-#' @importFrom cli cat_line
-#' @importFrom purrr map_int map map2_int
-#' @importFrom purrr prepend
 print_blr_reg <- function(x) {
   w1 <- max(nchar("Data Set"), nchar(x$dataname))
   w2 <- max(nchar("Resp Var"), nchar(x$resp_name))
@@ -25,10 +22,8 @@ print_blr_reg <- function(x) {
   )
   cat(rep("-", w7), sep = "", "\n\n")
 
-  w8 <- nchar("Outcome")
-  w9 <- c("Frequency", x$resp_prof[[1]], x$resp_prof[[2]]) %>%
-    map_int(nchar) %>%
-    max()
+  w8  <- nchar("Outcome")
+  w9  <- max(nchar(c("Frequency", x$resp_prof[[1]], x$resp_prof[[2]])))
   w10 <- sum(w8, w9, w8, w9, 24)
 
   cat(fc("Response Summary", w10), "\n")
@@ -44,22 +39,12 @@ print_blr_reg <- function(x) {
   )
   cat(rep("-", w10), sep = "", "\n\n")
 
-  w11 <- c("Parameter", x$parameter) %>%
-    map_int(nchar) %>%
-    max()
+  w11 <- max(nchar(c("Parameter", x$parameter)))
   w12 <- 2
-  w13 <- c("Estimate", format(round(x$est, 4), nsmall = 4)) %>%
-    map_int(nchar) %>%
-    max()
-  w14 <- c("Std.Error", format(round(x$se, 4), nsmall = 4)) %>%
-    map_int(nchar) %>%
-    max()
-  w15 <- c("z value", format(round(x$zval, 4), nsmall = 4)) %>%
-    map_int(nchar) %>%
-    max()
-  w16 <- c("Pr(>|z|)", format(round(x$pval, 4), nsmall = 4)) %>%
-    map_int(nchar) %>%
-    max()
+  w13 <- max(nchar(c("Estimate", format(round(x$est, 4), nsmall = 4))))
+  w14 <- max(nchar(c("Std.Error", format(round(x$se, 4), nsmall = 4))))
+  w15 <- max(nchar(c("z value", format(round(x$zval, 4), nsmall = 4))))
+  w16 <- max(nchar(c("Pr(>|z|)", format(round(x$pval, 4), nsmall = 4))))
   w17 <- sum(w11, w12, w13, w14, w15, w16, 20)
 
   mln <- length(x$parameter)
@@ -86,24 +71,13 @@ print_blr_reg <- function(x) {
   if (x$odds_conf) {
 
     # odds ration estimates
-    w18 <- c("Odds Ratio", x$blr_effects) %>%
-      nchar() %>%
-      max()
-    w19 <- c("Estimate", x$blr_odds_point) %>%
-      nchar() %>%
-      max()
-    w20 <- x$blr_conf %>%
-      use_series(`2.5 %`) %>%
-      format(round(4), nsmall = 4) %>%
-      prepend("95% Wald") %>%
-      nchar() %>%
-      max()
-    w21 <- x$blr_conf %>%
-      use_series(`97.5 %`) %>%
-      format(round(4), nsmall = 4) %>%
-      prepend("Conf. Limit") %>%
-      nchar() %>%
-      max()
+    w18 <- max(nchar(c("Odds Ratio", x$blr_effects)))
+    w19 <- max(nchar(c("Estimate", x$blr_odds_point)))
+    w20 <- max(nchar(c("95% Wald", format(x$blr_conf$`2.5 %`,
+      round(4), nsmall = 4))))
+
+    w21 <- max(nchar(c("Conf. Limit", format(x$blr_conf$`97.5 %`,
+      round(4), nsmall = 4))))
 
     w22 <- sum(w18, w19, w20, w21, 12)
 
@@ -120,8 +94,8 @@ print_blr_reg <- function(x) {
       cat(
         fc(x$blr_effects[i], w18), fs(),
         fc(format(round(x$blr_odds_point[i], 4), nsmall = 4), w19), fs(),
-        fc(format(round(x$blr_conf$`2.5 %`[i], 4), nsmall = 4), w20),
-        fs(), fg(format(round(x$blr_conf$`97.5 %`[i], 4), nsmall = 4), w21), "\n"
+        fc(format(round(x$blr_conf[[1]][i], 4), nsmall = 4), w20),
+        fs(), fg(format(round(x$blr_conf[[2]][i], 4), nsmall = 4), w21), "\n"
       )
     }
     cat(rep("-", w22), sep = "", "\n\n")
@@ -130,19 +104,9 @@ print_blr_reg <- function(x) {
 
 
   w23 <- 12
-  w24 <- x$blr_cord %>%
-    extract(1:4) %>%
-    unlist(use.names = FALSE) %>%
-    format(round(4), nsmall = 4) %>%
-    nchar() %>%
-    max()
+  w24 <- max(nchar(format(unlist(x$blr_cord[1:4], use.names = FALSE), nsmall = 4)))
   w25 <- 9
-  w26 <- x$blr_cord %>%
-    extract(5:8) %>%
-    unlist(use.names = FALSE) %>%
-    format(round(4), nsmall = 4) %>%
-    nchar() %>%
-    max()
+  w26 <- max(nchar(format(unlist(x$blr_cord[5:8], use.names = FALSE), nsmall = 4)))
   w27 <- sum(w23, w24, w25, w26, 21)
 
   cat(fc("Association of Predicted Probabilities and Observed Responses", w27), "\n")
@@ -173,58 +137,14 @@ print_blr_reg <- function(x) {
   )
   cat(rep("-", w27), sep = "", "\n\n")
 
-  # model fit stats
-  # w28 <- 24
-  # w30 <- 27
-  # w29 <- c(x$modfit$loglik_null, x$modfit$m_deviance, x$modfit$m_bic) %>%
-  #   format(round(3), nsmall = 3) %>%
-  #   nchar %>%
-  #   max
-  # w31 <- c(x$modfit$loglik_model, x$modfit$lr_ratio, x$modfit$m_aic) %>%
-  #   format(round(3), nsmall = 3) %>%
-  #   nchar %>%
-  #   max
-  # w <- sum(w28, w29, w30, w31, 12)
-  #
-  # cat(fc('Model Fit Statistics', w), '\n')
-  # cat(rep("-", w), sep = "", '\n')
-  # col1names <- c('Log-Lik Intercept Only:', glue('Deviance(', x$modfit$dev_df, '):'), '',
-  #                "MCFadden's R2", 'ML (Cox-Snell) R2:',
-  #                "McKelvey & Zavoina's R2:", 'Count R2:', 'BIC:')
-  # col3names <- c('Log-Lik Full Model:', glue('LR(', x$modfit$lr_df, '):'), 'Prob > LR:',
-  #                "McFadden's Adj R2:", "Cragg-Uhler(Nagelkerke) R2:",
-  #                "Efron's R2:", "Adj Count R2:", "AIC:")
-  # col2vals <- c(x$modfit$loglik_null, x$modfit$m_deviance, x$modfit$mcfadden, x$modfit$cox_snell,
-  #               x$modfit$mckelvey, x$modfit$count_r2, x$modfit$m_bic) %>%
-  #   round(3) %>%
-  #   format(nsmall = 3) %>%
-  #   prepend(value = '', before = 3)
-  # col4vals <- c(x$modfit$loglik_model, x$modfit$lr_ratio, x$modfit$lr_pval, x$modfit$adj_mcfadden,
-  #               x$modfit$nagelkerke, x$modfit$effron, x$modfit$count_adj, x$modfit$m_aic) %>%
-  #   round(3) %>%
-  #   format(nsmall = 3)
-  # nlen <- length(col3names)
-  # for (i in seq_len(nlen)) {
-  #   cat(fl(col1names[i], w28), fs(),
-  #       fg(col2vals[i], w29), fs(),
-  #       fl(col3names[i], w30), fs(),
-  #       fg(col4vals[i], w31), '\n')
-  # }
-  # cat(rep("-", w), sep = "", '\n\n')
 }
 
 
 print_model_fit_stats <- function(x) {
   w1 <- 24
   w3 <- 27
-  w2 <- c(x$loglik_null, x$m_deviance, x$m_bic) %>%
-    format(round(3), nsmall = 3) %>%
-    nchar() %>%
-    max()
-  w4 <- c(x$loglik_model, x$lr_ratio, x$m_aic) %>%
-    format(round(3), nsmall = 3) %>%
-    nchar() %>%
-    max()
+  w2 <- max(nchar(format(c(x$loglik_null, x$m_deviance, x$m_bic), nsmall = 3)))
+  w4 <- max(nchar(format(c(x$loglik_model, x$lr_ratio, x$m_aic), nsmall = 3)))
   w <- sum(w1, w2, w3, w4, 12)
 
   cat(fc("Model Fit Statistics", w), "\n")
@@ -239,19 +159,13 @@ print_model_fit_stats <- function(x) {
     "McFadden's Adj R2:", "Cragg-Uhler(Nagelkerke) R2:",
     "Efron's R2:", "Adj Count R2:", "AIC:"
   )
-  col2vals <- c(
-    x$loglik_null, x$m_deviance, x$mcfadden, x$cox_snell,
-    x$mckelvey, x$count_r2, x$m_bic
-  ) %>%
-    round(3) %>%
-    format(nsmall = 3) %>%
-    prepend(values = "", before = 3)
-  col4vals <- c(
-    x$loglik_model, x$lr_ratio, x$lr_pval, x$adj_mcfadden,
-    x$nagelkerke, x$effron, x$count_adj, x$m_aic
-  ) %>%
-    round(3) %>%
-    format(nsmall = 3)
+  col2vec <- c(x$loglik_null, x$m_deviance, x$mcfadden, x$cox_snell, x$mckelvey,
+               x$count_r2, x$m_bic)
+  col2vals <- append(x = format(round(col2vec, 3), nsmall = 3), values = "",
+                     after = 2)
+  col4vals <- format(round(c(x$loglik_model, x$lr_ratio, x$lr_pval,
+                             x$adj_mcfadden, x$nagelkerke, x$effron,
+                             x$count_adj, x$m_aic), 3), nsmall = 3)
   nlen <- length(col3names)
   for (i in seq_len(nlen)) {
     cat(
@@ -268,15 +182,10 @@ print_model_fit_stats <- function(x) {
 print_bivariate_analysis <- function(x) {
   w1 <- max(nchar(c("Variable", x$variable)))
   w2 <- max(nchar(c("Information Value", x$iv)))
-  w3 <- max(nchar(c("LR Chi Square", format(
-    round(x$likelihood_ratio, 4),
-    nsmall = 4
-  ))))
+  w3 <- max(nchar(c("LR Chi Square", format(round(x$likelihood_ratio, 4),
+                                            nsmall = 4))))
   w4 <- max(nchar(c("LR DF", x$df)))
-  w5 <- max(nchar(c("LR p-value", format(
-    round(x$pval, 4),
-    nsmall = 4
-  ))))
+  w5 <- max(nchar(c("LR p-value", format(round(x$pval, 4),nsmall = 4))))
   w <- sum(w1, w2, w3, w4, w5, 16)
 
   cat(fc("Bivariate Analysis", w), "\n")
@@ -301,39 +210,17 @@ print_bivariate_analysis <- function(x) {
 
 
 print_blr_segment <- function(x) {
-  y1 <- x %>%
-    use_series(segment_data) %>%
-    map(as.character) %>%
-    map(nchar) %>%
-    map_int(max) %>%
-    unname()
 
-  y2 <- x %>%
-    use_series(segment_data) %>%
-    names() %>%
-    nchar()
+  y1 <- unname(sapply(lapply(lapply(x$segment, as.character), nchar), max))
+  y2 <- nchar(names(x$segment_data))
+  w  <- mapply(max, y1, y2)
 
-  w <- map2_int(y1, y2, max)
-  wsum <- sum(w, 11)
-
-  rnames <- x %>%
-    use_series(segment_data) %>%
-    names()
-
-  dtable <- x %>%
-    use_series(segment_data)
-
-  c1 <- dtable %>%
-    pull(rnames[1]) %>%
-    prepend(rnames[1])
-
-  c2 <- dtable %>%
-    pull(rnames[2]) %>%
-    round(2) %>%
-    format(nsamll = 2) %>%
-    prepend(rnames[2])
-
-  clen <- length(c1)
+  wsum   <- sum(w, 11)
+  rnames <- names(x$segment_data)
+  dtable <- x$segment_data
+  c1     <- c(rnames[1], dtable[[rnames[1]]])
+  c2     <- c(rnames[2], format(round(dtable[[rnames[2]]], 2), nsmall = 2))
+  clen   <- length(c1)
 
   cat(fc("Event By Attributes", wsum), "\n")
   cat(rep("-", wsum), sep = "", "\n")
@@ -348,54 +235,19 @@ print_blr_segment <- function(x) {
 
 
 print_blr_segment_dist <- function(x) {
-  y1 <- x %>%
-    use_series(dist_table) %>%
-    map(as.character) %>%
-    map(nchar) %>%
-    map_int(max) %>%
-    unname()
 
-  y2 <- x %>%
-    use_series(dist_table) %>%
-    names() %>%
-    nchar()
-
-  w <- map2_int(y1, y2, max)
-  wsum <- sum(w, 16)
-
-  rnames <- x %>%
-    use_series(dist_table) %>%
-    names()
-
-  dtable <- x %>%
-    use_series(dist_table)
-
-  c1 <- dtable %>%
-    pull(rnames[1]) %>%
-    prepend(x %>%
-      use_series(var_name))
-
-  c2 <- dtable %>%
-    pull(rnames[2]) %>%
-    prepend(rnames[2])
-
-  c3 <- dtable %>%
-    pull(rnames[3]) %>%
-    prepend(rnames[3])
-
-  c4 <- dtable %>%
-    pull(rnames[4]) %>%
-    round(2) %>%
-    format(nsamll = 2) %>%
-    prepend(rnames[4])
-
-  c5 <- dtable %>%
-    pull(rnames[5]) %>%
-    round(2) %>%
-    format(nsamll = 2) %>%
-    prepend(rnames[5])
-
-  clen <- length(c1)
+  y1     <- unname(sapply(lapply(lapply(x$dist_table, as.character), nchar), max))
+  y2     <- nchar(names(x$dist_table))
+  w      <- mapply(max, y1, y2)
+  wsum   <- sum(w, 16)
+  rnames <- names(x$dist_table)
+  dtable <- x$dist_table
+  c1     <- c(x$var_name, dtable[[rnames[1]]])
+  c2     <- c(rnames[2], dtable[[rnames[2]]])
+  c3     <- c(rnames[3], dtable[[rnames[3]]])
+  c4     <- c(rnames[4], format(round(dtable[[rnames[4]]], 2), nsmall = 2))
+  c5     <- c(rnames[5], format(round(dtable[[rnames[5]]], 2), nsmall = 2))
+  clen   <- length(c1)
 
   cat(fc("Event Segmentation", wsum), "\n")
   cat(rep("-", wsum), sep = "", "\n")
@@ -414,45 +266,17 @@ print_blr_segment_dist <- function(x) {
 
 print_blr_test_hosmer_lemeshow <- function(x) {
   w1 <- nchar("group")
-  w2 <- x %>%
-    use_series(partition_table) %>%
-    use_series(n) %>%
-    prepend("Total") %>%
-    nchar() %>%
-    max()
-  w3 <- x %>%
-    use_series(partition_table) %>%
-    use_series(`1s_observed`) %>%
-    prepend("Observed") %>%
-    nchar() %>%
-    max()
-  w4 <- x %>%
-    use_series(partition_table) %>%
-    use_series(`1s_expected`) %>%
-    round(2) %>%
-    format(nsmall = 2) %>%
-    prepend("Expected") %>%
-    nchar() %>%
-    max()
-  w5 <- x %>%
-    use_series(partition_table) %>%
-    use_series(`0s_observed`) %>%
-    prepend("Observed") %>%
-    nchar() %>%
-    max()
-  w6 <- x %>%
-    use_series(partition_table) %>%
-    use_series(`0s_expected`) %>%
-    round(2) %>%
-    format(nsmall = 2) %>%
-    prepend("Expected") %>%
-    nchar() %>%
-    max()
+  w2 <- max(nchar(c("Total", x$partition_table$n)))
+  w3 <- max(nchar(c("Observed", x$partition_table$`1s_observed`)))
+  w4 <- max(nchar(c("Expected", format(round(x$partition_table$`1s_expected`,
+                                             2), nsmall = 2))))
+  w5 <- max(nchar(c("Observed", x$partition_table$`0s_observed`)))
+  w6 <- max(nchar(c("Expected", format(round(x$partition_table$`0s_expected`,
+                                             2), nsmall = 2))))
   w7 <- w3 + w4 + 4
   w8 <- w5 + w6 + 4
-  w <- sum(w1, w2, w3, w4, w5, w6, 20)
-  j <- x %>%
-    use_series(partition_table)
+  w  <- sum(w1, w2, w3, w4, w5, w6, 20)
+  j  <- x$partition_table
 
   cat(fc("Partition for the Hosmer & Lemeshow Test", w), "\n")
   cat(rep("-", w), sep = "", "\n")
@@ -475,13 +299,7 @@ print_blr_test_hosmer_lemeshow <- function(x) {
   }
   cat(rep("-", w), sep = "", "\n\n")
 
-  w9 <- x %>%
-    use_series(chisq_stat) %>%
-    round(4) %>%
-    format(nsmall = 4) %>%
-    prepend("Chi-Square") %>%
-    nchar() %>%
-    max()
+  w9 <- max(nchar(c("Chi-Square", format(round(x$chisq_stat, 4), nsmall = 4))))
   w10 <- 2
   w11 <- 10
   w12 <- sum(w9, w10, w11, 8)
@@ -503,25 +321,13 @@ print_blr_test_hosmer_lemeshow <- function(x) {
 
 
 print_blr_lr_test <- function(x) {
-  w9 <- x %>%
-    use_series(test_result) %>%
-    pull(lr_ratio) %>%
-    round(4) %>%
-    format(nsmall = 4) %>%
-    prepend("Chi-Square") %>%
-    nchar() %>%
-    max()
-  w10 <- x %>%
-    use_series(test_result) %>%
-    pull(d_f) %>%
-    prepend("DF") %>%
-    nchar() %>%
-    max()
+
+  w9  <- max(nchar(c("Chi-Square", format(round(x$test_result[['lr_ratio']], 4),
+                                         nsmall = 4))))
+  w10 <- max(nchar(c("DF", x$test_result[['d_f']])))
   w11 <- 10
   w12 <- sum(w9, w10, w11, 8)
-
-  j <- x %>%
-    use_series(test_result)
+  j   <- x$test_result
 
   cat(fc("Likelihood Ratio Test", w12), "\n")
   cat(rep("-", w12), sep = "", "\n")
@@ -539,63 +345,21 @@ print_blr_lr_test <- function(x) {
 }
 
 print_blr_woe_iv <- function(x) {
-  y1 <- x %>%
-    use_series(woe_iv_table) %>%
-    map(nchar) %>%
-    map_int(max)
 
-  y2 <- x %>%
-    use_series(woe_iv_table) %>%
-    names() %>%
-    nchar()
-
-  w <- map2_int(y1, y2, max)
-  wsum <- sum(w, 24)
-
-  rnames <- x %>%
-    use_series(woe_iv_table) %>%
-    names()
-
-  woe_iv <- x %>%
-    use_series(woe_iv_table)
-
-  c1 <- woe_iv %>%
-    pull(rnames[1]) %>%
-    prepend(rnames[1])
-
-  c2 <- woe_iv %>%
-    pull(rnames[2]) %>%
-    prepend(rnames[2])
-
-  c3 <- woe_iv %>%
-    pull(rnames[3]) %>%
-    prepend(rnames[3])
-
-  c4 <- woe_iv %>%
-    pull(rnames[4]) %>%
-    round(2) %>%
-    format(nsmall = 2) %>%
-    prepend(rnames[4])
-
-  c5 <- woe_iv %>%
-    pull(rnames[5]) %>%
-    round(2) %>%
-    format(nsmall = 2) %>%
-    prepend(rnames[5])
-
-  c6 <- woe_iv %>%
-    pull(rnames[6]) %>%
-    round(2) %>%
-    format(nsmall = 2) %>%
-    prepend(rnames[6])
-
-  c7 <- woe_iv %>%
-    pull(rnames[7]) %>%
-    round(2) %>%
-    format(nsmall = 2) %>%
-    prepend(rnames[7])
-
-  clen <- length(c1)
+  woe_iv <- x$woe_iv_table
+  rnames <- names(woe_iv)
+  y1     <- sapply(lapply(lapply(woe_iv, as.character), nchar), max)
+  y2     <- nchar(rnames)
+  w      <- mapply(max, y1, y2)
+  wsum   <- sum(w, 24)
+  c1     <- c(rnames[1], woe_iv[[rnames[1]]])
+  c2     <- c(rnames[2], woe_iv[[rnames[2]]])
+  c3     <- c(rnames[3], woe_iv[[rnames[3]]])
+  c4     <- c(rnames[4], format(round(woe_iv[[rnames[4]]], 2), nsmall = 2))
+  c5     <- c(rnames[5], format(round(woe_iv[[rnames[5]]], 2), nsmall = 2))
+  c6     <- c(rnames[6], format(round(woe_iv[[rnames[6]]], 2), nsmall = 2))
+  c7     <- c(rnames[7], format(round(woe_iv[[rnames[7]]], 2), nsmall = 2))
+  clen   <- length(c1)
 
   cat(fc("Weight of Evidence", wsum), "\n")
   cat(rep("-", wsum), sep = "", "\n")
@@ -612,15 +376,10 @@ print_blr_woe_iv <- function(x) {
   }
   cat(rep("-", wsum), sep = "", "\n\n")
 
-  l1 <- c("Variable", x$var_name) %>%
-    nchar() %>%
-    max()
-  l2 <- 17
-  lsum <- sum(l1, l2, 4)
-
-  ivalue <- woe_iv %>%
-    pull(iv) %>%
-    sum()
+  l1     <- max(nchar(c("Variable", x$var_name)))
+  l2     <- 17
+  lsum   <- sum(l1, l2, 4)
+  ivalue <- sum(woe_iv[['iv']])
 
   cat(fc("Information Value", lsum), "\n")
   cat(rep("-", lsum), sep = "", "\n")
@@ -646,12 +405,6 @@ print_forward_selection <- function(data) {
 
   ln <- length(data$aics)
 
-  # cat(format("Forward Selection Method", justify = "left", width = w), "\n")
-  # cat(rep("-", 24), sep = "", '\n\n')
-  # cat(format("Candidate Terms:", justify = "left", width = w), "\n\n")
-  # for (i in seq_len(length(data$candidates))) {
-  #     cat(format(paste(i, ".", data$candidates[i]), justify = "left", width = w), "\n")
-  # }
   cat("\n")
   cat(format("Selection Summary", justify = "centre", width = w), "\n")
   cat(rep("-", w), sep = "", "\n")
@@ -679,14 +432,14 @@ print_backward_elimination <- function(data) {
 
   # width
   w1 <- max(nchar("Full Model"), nchar(data$predictors))
-  w2 <- max(nchar("AIC"), nchar(format(round(data$aics, 3), nsmall = 3)))
-  w3 <- max(nchar("BIC"), nchar(format(round(data$bics, 3), nsmall = 3)))
-  w4 <- max(nchar("Deviance"), nchar(format(round(data$devs, 3), nsmall = 3)))
+  w2 <- max(nchar("AIC"), nchar(format(round(data$result$aic, 3), nsmall = 3)))
+  w3 <- max(nchar("BIC"), nchar(format(round(data$result$bic, 3), nsmall = 3)))
+  w4 <- max(nchar("Deviance"), nchar(format(round(data$result$deviance, 3), nsmall = 3)))
   w <- sum(w1, w2, w3, w4, 12)
 
   predictors <- c("Full Model", data$predictors)
 
-  ln <- length(data$aics)
+  ln <- length(data$result$aic)
 
   cat("\n\n", format("Backward Elimination Summary", width = w, justify = "centre"), "\n")
   cat(rep("-", w), sep = "", "\n")
@@ -697,9 +450,9 @@ print_backward_elimination <- function(data) {
   cat(rep("-", w), sep = "", "\n")
   for (i in seq_len(ln)) {
     cat(
-      fl(predictors[i], w1), fs(), fg(format(round(data$aics[i], 3), nsmall = 3), w2), fs(),
-      fg(format(round(data$bics[i], 3), nsmall = 3), w3), fs(),
-      fg(format(round(data$devs[i], 3), nsmall = 3), w4), "\n"
+      fl(predictors[i], w1), fs(), fg(format(round(data$result$aic[i], 3), nsmall = 3), w2), fs(),
+      fg(format(round(data$result$bic[i], 3), nsmall = 3), w3), fs(),
+      fg(format(round(data$result$deviance[i], 3), nsmall = 3), w4), "\n"
     )
   }
   cat(rep("-", w), sep = "", "\n\n")
@@ -741,34 +494,17 @@ print_stepwise_selection <- function(data) {
 
 
 print_blr_twoway_segment <- function(x) {
-  cnames <- x %>%
-    use_series(twoway_segment) %>%
-    colnames() %>%
-    prepend(x %>%
-      use_series(varnames) %>%
-      extract(1))
 
-  k <- x %>%
-    use_series(twoway_segment) %>%
-    rownames() %>%
-    cbind(x %>%
-      use_series(twoway_segment) %>%
-      round(3) %>%
-      format(nsmall = 3))
+  cnames <- c(x$varnames[1], colnames(x$twoway_segment))
+  k      <- cbind(rownames(x$twoway_segment),
+                  format(round(x$twoway_segment, 3), nsmall = 3))
+  nc     <- ncol(k)
+  nr     <- nrow(k)
+  wc     <- max(nchar(k))
+  vname  <- x$varnames[2]
+  w      <- (nc * wc) + (4 * (nc - 1))
+  w2     <- w - wc - 4 - 3
 
-  nc <- ncol(k)
-  nr <- nrow(k)
-
-  wc <- k %>%
-    nchar() %>%
-    max()
-
-  vname <- x %>%
-    use_series(varnames) %>%
-    extract(2)
-
-  w <- (nc * wc) + (4 * (nc - 1))
-  w2 <- w - wc - 4 - 3
   cat(paste0(rep(" ", wc)), fs(), fc(vname, w2), "\n")
   cat(rep("-", w), sep = "", "\n")
   for (i in seq_len(nc)) {
@@ -787,6 +523,7 @@ print_blr_twoway_segment <- function(x) {
 
 
 print_step_backward <- function(data) {
+
   n <- data$steps
 
   if (n < 1) {
