@@ -34,6 +34,7 @@ blr_regress.default <- function(object, data, odd_conf_limit = FALSE, ...) {
 	blr_check_logic(odd_conf_limit)
 
   result <- blr_reg_comp(object, data, odd_conf_limit)
+  
   class(result) <- "blr_regress"
   return(result)
 
@@ -46,8 +47,10 @@ blr_regress.glm <- function(object, odd_conf_limit = FALSE, ...) {
 
 	blr_check_model(object)
 	blr_check_logic(odd_conf_limit)
+
   formula <- formula(object)
-  data    <- eval(object$call$data)
+  data    <- object$model
+
   blr_regress.default(object = formula, data = data, odd_conf_limit = odd_conf_limit)
 }
 
