@@ -12,6 +12,7 @@
 #' @param details Logical; if \code{TRUE}, will print the regression result at
 #'   each step.
 #' @param x An object of class \code{blr_step_p_backward}.
+#' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #' @param ... Other inputs.
 #'
 #' @return \code{blr_step_p_backward} returns an object of class \code{"blr_step_p_backward"}.
@@ -47,7 +48,6 @@
 #'
 #' }
 #'
-#' @importFrom dplyr full_join select
 #'
 #' @family variable selection procedures
 #'
@@ -87,7 +87,7 @@ blr_step_p_backward.default <- function(model, prem = 0.3, details = FALSE, ...)
   }
   cat("\n")
 
-  cat(crayon::bold$red("We are eliminating variables based on p value..."))
+  cat("We are eliminating variables based on p value...")
   cat("\n")
 
   cat("\n")
@@ -99,10 +99,6 @@ blr_step_p_backward.default <- function(model, prem = 0.3, details = FALSE, ...)
     m <- glm(paste(response, "~", paste(preds, collapse = " + ")), l, family = binomial(link = 'logit'))
     m_sum <- Anova(m, test.statistic = "Wald")
     pvals <- m_sum$`Pr(>Chisq)`
-    # m_sum <- summary(m)
-    # pvals <- unname(m_sum$coefficients[, 4])[-1]
-    # m <- ols_regress(paste(response, "~", paste(preds, collapse = " + ")), l)
-    # pvals <- m$pvalues[-1]
     maxp  <- which(pvals == max(pvals))
 
     suppressWarnings(
@@ -120,12 +116,12 @@ blr_step_p_backward.default <- function(model, prem = 0.3, details = FALSE, ...)
         dev    <- c(dev, mfs$m_deviance)
 
         if (interactive()) {
-          cat(crayon::red(clisymbols::symbol$cross), crayon::bold(dplyr::last(rpred)), "\n")
+          cat(paste("-", rev(rpred)[1]), "\n")
         } else {
-          cat(paste("-", dplyr::last(rpred)), "\n")
+          cat(paste("-", rev(rpred)[1]), "\n")
         }
 
-        if (details == TRUE) {
+        if (details) {
           cat("\n")
           cat(paste("Backward Elimination: Step", step, "\n\n"), paste("Variable", rpred[lp], "Removed"), "\n\n")
           m <- blr_regress(paste(response, "~", paste(preds, collapse = " + ")), l)
@@ -135,18 +131,18 @@ blr_step_p_backward.default <- function(model, prem = 0.3, details = FALSE, ...)
       } else {
         end <- TRUE
         cat("\n")
-        cat(crayon::bold$red(paste0("No more variables satisfy the condition of p value = ", prem)))
+        cat("No more variables satisfy the condition of p value = ", prem)
         cat("\n")
       }
     )
   }
 
-  if (details == TRUE) {
+  if (details) {
     cat("\n\n")
     cat("Variables Removed:", "\n\n")
     for (i in seq_len(length(rpred))) {
       if (interactive()) {
-        cat(crayon::red(clisymbols::symbol$cross), crayon::bold(rpred[i]), "\n")
+        cat(paste("-", rpred[i]), "\n")
       } else {
         cat(paste("-", rpred[i]), "\n")
       }
@@ -194,27 +190,28 @@ print.blr_step_p_backward <- function(x, ...) {
 #' @export
 #' @rdname blr_step_p_backward
 #'
-plot.blr_step_p_backward <- function(x, model = NA, ...) {
+plot.blr_step_p_backward <- function(x, model = NA, print_plot = TRUE, ...) {
 
   a <- NULL
   b <- NULL
 
   y <- seq_len(x$steps)
 
-  d4 <- tibble(a = y, b = x$aic)
-  d5 <- tibble(a = y, b = x$bic)
-  d6 <- tibble(a = y, b = x$dev)
+  d4 <- data.frame(a = y, b = x$aic)
+  d5 <- data.frame(a = y, b = x$bic)
+  d6 <- data.frame(a = y, b = x$dev)
 
   p4 <- plot_stepwise(d4, "AIC")
   p5 <- plot_stepwise(d5, "BIC")
   p6 <- plot_stepwise(d6, "Deviance")
 
-  # grid.arrange(p1, p2, p3, p4, p5, p6, ncol = 2, top = "Stepwise Backward Regression")
-
-  myplots <- list(plot_4 = p4, plot_5 = p5, plot_6 = p6)
-  result <- marrangeGrob(myplots, nrow = 2, ncol = 2)
-  result
-
+  myplots <- list(aic = p4, bic = p5, deviance = p6)
+  
+  if (print_plot) {
+    gridExtra::marrangeGrob(myplots, nrow = 2, ncol = 2)
+  }
+  
+  invisible(myplots)
 }
 
 
