@@ -22,14 +22,9 @@ test_that("blr_bivariate_analysis prints the correct output", {
 })
 
 test_that("output from blr_segment is as expected", {
-  k <- blr_segment(hsb2, honcomp, race)
-
-  actual <-
-    k %>%
-    use_series(segment_data) %>%
-    pull(`1s%`) %>%
-    dplyr::last()
-
+  
+  k        <- blr_segment(hsb2, honcomp, race)
+  actual   <- rev(k$segment_data[['1s%']])[1]
   expected <- c(0.22)
 
   expect_equivalent(actual, expected)
@@ -53,8 +48,8 @@ test_that("blr_segment prints the correct output", {
 
 test_that("output from blr_twoway_segment is as expected", {
 
-  k <- blr_segment_twoway(hsb2, honcomp, prog, race)
-  actual <- unname(round(k$twoway_segment[, 4], 3))
+  k        <- blr_segment_twoway(hsb2, honcomp, prog, race)
+  actual   <- unname(round(k$twoway_segment[, 4], 3))
   expected <- c(0.035, 0.165, 0.020)
   expect_equivalent(actual, expected)
 })
@@ -79,12 +74,9 @@ test_that("blr_twoway_segment prints the correct output", {
 })
 
 test_that("output from blr_segment_dist is as expected", {
-  k <- blr_segment_dist(hsb2, honcomp, race)
-  actual <-
-    k %>%
-    use_series(dist_table) %>%
-    pull(`1s%`) %>%
-    dplyr::last()
+  
+  k        <- blr_segment_dist(hsb2, honcomp, race)
+  actual   <- rev(k$dist_table[['1s%']])[1]
   expected <- c(0.22)
   expect_equivalent(actual, expected)
 })
@@ -109,12 +101,8 @@ test_that("blr_twoway_segment prints the correct output", {
 
 
 test_that("output from blr_woe_iv is as expected", {
-  k <- blr_woe_iv(hsb2, prog, honcomp)
-  actual <-
-    k %>%
-    use_series(woe_iv_table) %>%
-    pull(iv) %>%
-    sum()
+  k        <- blr_woe_iv(hsb2, prog, honcomp)
+  actual   <- sum(k$woe_iv_table[['iv']])
   expected <- 0.4329
   expect_equal(actual, expected)
 })
@@ -123,22 +111,21 @@ test_that("blr_woe_iv prints the correct output", {
   k <- blr_woe_iv(hsb2, prog, honcomp)
 
   x <- cat(
-    "                           Weight of Evidence
+    "                           Weight of Evidence                             
+-------------------------------------------------------------------------
+levels    count_0s    count_1s    dist_0s    dist_1s        woe      iv   
+-------------------------------------------------------------------------
+  1          38          7           0.26       0.13       0.67     0.08  
+  2          65          40          0.44       0.75      -0.53     0.17  
+  3          44          6           0.30       0.11       0.97     0.18  
 -------------------------------------------------------------------------
-    levels    0s_count    1s_count    0s_dist    1s_dist        woe      iv
-    -------------------------------------------------------------------------
-    1          38          7           0.26       0.13       0.67     0.08
-    2          65          40          0.44       0.75      -0.53     0.17
-    3          44          6           0.30       0.11       0.97     0.18
-    -------------------------------------------------------------------------
 
-    Information Value
-    -----------------------------
-    Variable    Information Value
-    -----------------------------
-    prog           0.4329
-    -----------------------------"
-  )
+      Information Value       
+-----------------------------
+Variable    Information Value 
+-----------------------------
+  prog           0.4329       
+-----------------------------")
 
   expect_output(print(k), x)
 })
@@ -150,76 +137,76 @@ test_that("output from blr_woe_iv_stats is as expected", {
 
   x <- cat("Variable: prog
 
-                           Weight of Evidence
+                           Weight of Evidence                             
 -------------------------------------------------------------------------
-levels    0s_count    1s_count    0s_dist    1s_dist        woe      iv
+levels    count_0s    count_1s    dist_0s    dist_1s        woe      iv   
 -------------------------------------------------------------------------
-  1          38          7           0.26       0.13       0.67     0.08
-  2          65          40          0.44       0.75      -0.53     0.17
-  3          44          6           0.30       0.11       0.97     0.18
+  1          38          7           0.26       0.13       0.67     0.08  
+  2          65          40          0.44       0.75      -0.53     0.17  
+  3          44          6           0.30       0.11       0.97     0.18  
 -------------------------------------------------------------------------
 
-      Information Value
+      Information Value       
 -----------------------------
-Variable    Information Value
+Variable    Information Value 
 -----------------------------
-  prog           0.4329
+  prog           0.4329       
 -----------------------------
 
 
 Variable: race
 
-                           Weight of Evidence
+                           Weight of Evidence                             
 -------------------------------------------------------------------------
-levels    0s_count    1s_count    0s_dist    1s_dist        woe      iv
+levels    count_0s    count_1s    dist_0s    dist_1s        woe      iv   
 -------------------------------------------------------------------------
-  1          22          2           0.15       0.04       1.38     0.15
-  2          6           5           0.04       0.09      -0.84     0.04
-  3          18          2           0.12       0.04       1.18     0.10
-  4         101          44          0.69       0.83      -0.19     0.03
+  1          22          2           0.15       0.04       1.38     0.15  
+  2          6           5           0.04       0.09      -0.84     0.04  
+  3          18          2           0.12       0.04       1.18     0.10  
+  4         101          44          0.69       0.83      -0.19     0.03  
 -------------------------------------------------------------------------
 
-      Information Value
+      Information Value       
 -----------------------------
-Variable    Information Value
+Variable    Information Value 
 -----------------------------
-  race            0.326
+  race            0.326       
 -----------------------------
 
 
 Variable: female
 
-                           Weight of Evidence
+                           Weight of Evidence                             
 -------------------------------------------------------------------------
-levels    0s_count    1s_count    0s_dist    1s_dist        woe      iv
+levels    count_0s    count_1s    dist_0s    dist_1s        woe      iv   
 -------------------------------------------------------------------------
-  0          73          18          0.50       0.34       0.38     0.06
-  1          74          35          0.50       0.66      -0.27     0.04
+  0          73          18          0.50       0.34       0.38     0.06  
+  1          74          35          0.50       0.66      -0.27     0.04  
 -------------------------------------------------------------------------
 
-      Information Value
+      Information Value       
 -----------------------------
-Variable    Information Value
+Variable    Information Value 
 -----------------------------
- female          0.1023
+ female          0.1023       
 -----------------------------
 
 
 Variable: schtyp
 
-                           Weight of Evidence
+                           Weight of Evidence                            
 ------------------------------------------------------------------------
-levels    0s_count    1s_count    0s_dist    1s_dist        woe     iv
+levels    count_0s    count_1s    dist_0s    dist_1s        woe     iv   
 ------------------------------------------------------------------------
-  1         123          45          0.84       0.85      -0.01    0.00
-  2          24          8           0.16       0.15       0.08    0.00
+  1         123          45          0.84       0.85      -0.01    0.00  
+  2          24          8           0.16       0.15       0.08    0.00  
 ------------------------------------------------------------------------
 
-      Information Value
+      Information Value       
 -----------------------------
-Variable    Information Value
+Variable    Information Value 
 -----------------------------
- schtyp          0.0012
+ schtyp          0.0012       
 -----------------------------")
 
   expect_output(print(k), x)
